==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/tr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "İstek jetonları getirme başarısız oldu. Uygulama anahtarınızın ve gizli bilginin doğruluğunu kontrol edin.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Erişim jetonları getirme başarısız oldu. Uygulama anahtarınızın ve gizli bilginin doğruluğunu kontrol edin.",
    "Please provide a valid app key and secret." : "Lütfen geçerli bir uygulama anahtarı ve gizli bilgisini girin.",
    "Step 1 failed. Exception: %s" : "Adım 1 başarısız. Özel durum: %s",
    "Step 2 failed. Exception: %s" : "Adım 2 başarısız. Özel durum: %s",
    "External storage" : "Harici depolama",
    "Storage with id \"%i\" not found" : "\"%i\" kimliği ile bir depolama bulunamadı",
    "Invalid backend or authentication mechanism class" : "Geçersiz arka uç veya kimlik doğrulama mekanizma sınıfı",
    "Invalid mount point" : "Geçersiz bağlama noktası",
    "Objectstore forbidden" : "Nesne deposu yasaktır",
    "Invalid storage backend \"%s\"" : "Geçersiz depolama arka ucu \"%s\"",
    "Not permitted to use backend \"%s\"" : "\"%s\" arka ucu kullanımına izin verilmiyor",
    "Not permitted to use authentication mechanism \"%s\"" : "\"%s\" kimlik doğrulama mekanizmasına izin verilmiyor",
    "Unsatisfied backend parameters" : "Yetersiz arka uç parametreleri",
    "Unsatisfied authentication mechanism parameters" : "Yetersiz kimlik doğrulama mekanizması parametreleri",
    "Personal" : "Kişisel",
    "System" : "Sistem",
    "Grant access" : "Erişimi sağla",
    "Access granted" : "Giriş kabul edildi",
    "Error configuring OAuth1" : "OAuth1 yapılandırma hatası",
    "Error configuring OAuth2" : "OAuth2 yapılandırma hatası",
    "Generate keys" : "Anahtarlar üret",
    "Error generating key pair" : "Anahtar çifti üretirken hata",
    "Enable encryption" : "Şifrelemeyi aç",
    "Enable previews" : "Önizlemeleri aç",
    "Check for changes" : "Değişiklikleri denetle",
    "Never" : "Daha yeni",
    "Once every direct access" : "Her doğrudan erişimde bir kez",
    "Every time the filesystem is used" : "Dosya sistemi her kullanıldığında",
    "All users. Type to select user or group." : "Tüm kullanıcılar. Kullanıcı veya grup seçmek için yazın.",
    "(group)" : "(grup)",
    "Saved" : "Kaydedildi",
    "Access key" : "Erişim anahtarı",
    "Secret key" : "Gizli anahtar",
    "Builtin" : "Yerleşik",
    "None" : "Hiçbiri",
    "OAuth1" : "OAuth1",
    "App key" : "Uyg. anahtarı",
    "App secret" : "Uyg. parolası",
    "OAuth2" : "OAuth2",
    "Client ID" : "İstemci kimliği",
    "Client secret" : "İstemci parolası",
    "OpenStack" : "OpenStack",
    "Username" : "Kullanıcı Adı",
    "Password" : "Parola",
    "Tenant name" : "Kiracı adı",
    "Identity endpoint URL" : "Kimlik uç nokta URL'si",
    "Rackspace" : "Rackspace",
    "API key" : "API anahtarı",
    "Username and password" : "Kullanıcı adı ve parola",
    "Session credentials" : "Oturum bilgileri",
    "RSA public key" : "RSA ortak anahtarı",
    "Public key" : "Ortak anahtar",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Makine adı",
    "Port" : "Port",
    "Region" : "Bölge",
    "Enable SSL" : "SSL'yi Etkinleştir",
    "Enable Path Style" : "Yol Biçemini Etkinleştir",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Uzak alt klasör",
    "Secure https://" : "Güvenli https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Sunucu",
    "Secure ftps://" : "Güvenli ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Yerel",
    "Location" : "Konum",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Kök",
    "SFTP with secret key login" : "Gizli anahtar oturumu ile SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Paylaş",
    "Domain" : "Alan adı",
    "SMB / CIFS using OC login" : "OC oturumu kullanarak SMB / CIFS",
    "Username as share" : "Paylaşım olarak kullanıcı adı",
    "OpenStack Object Storage" : "OpenStack Nesne Depolama",
    "Service name" : "Hizmet adı",
    "Request timeout (seconds)" : "İstek zamanaşımı (saniye)",
    "<b>Note:</b> " : "<b>Not:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> PHP'de cURL desteği etkin veya kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> PHP'de FTP desteği etkin veya kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> \"%s\" kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "No external storage configured" : "Yapılandırılmış harici depolama yok",
    "You can add external storages in the personal settings" : "Harici depolamaları kişisel ayarlar içerisinden ekleyebilirsiniz",
    "Name" : "Ad",
    "Storage type" : "Depolama türü",
    "Scope" : "Kapsam",
    "External Storage" : "Harici Depolama",
    "Folder name" : "Klasör ismi",
    "Authentication" : "Kimlik Doğrulama",
    "Configuration" : "Yapılandırma",
    "Available for" : "Kullanabilenler",
    "Advanced settings" : "Gelişmiş ayarlar",
    "Delete" : "Sil",
    "Add storage" : "Depo ekle",
    "Enable User External Storage" : "Kullanıcılar için Harici Depolamayı Etkinleştir",
    "Allow users to mount the following external storage" : "Kullanıcıların aşağıdaki harici depolamayı bağlamalarına izin ver"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/tr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "İstek jetonları getirme başarısız oldu. Uygulama anahtarınızın ve gizli bilginin doğruluğunu kontrol edin.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Erişim jetonları getirme başarısız oldu. Uygulama anahtarınızın ve gizli bilginin doğruluğunu kontrol edin.",
    "Please provide a valid app key and secret." : "Lütfen geçerli bir uygulama anahtarı ve gizli bilgisini girin.",
    "Step 1 failed. Exception: %s" : "Adım 1 başarısız. Özel durum: %s",
    "Step 2 failed. Exception: %s" : "Adım 2 başarısız. Özel durum: %s",
    "External storage" : "Harici depolama",
    "Storage with id \"%i\" not found" : "\"%i\" kimliği ile bir depolama bulunamadı",
    "Invalid backend or authentication mechanism class" : "Geçersiz arka uç veya kimlik doğrulama mekanizma sınıfı",
    "Invalid mount point" : "Geçersiz bağlama noktası",
    "Objectstore forbidden" : "Nesne deposu yasaktır",
    "Invalid storage backend \"%s\"" : "Geçersiz depolama arka ucu \"%s\"",
    "Not permitted to use backend \"%s\"" : "\"%s\" arka ucu kullanımına izin verilmiyor",
    "Not permitted to use authentication mechanism \"%s\"" : "\"%s\" kimlik doğrulama mekanizmasına izin verilmiyor",
    "Unsatisfied backend parameters" : "Yetersiz arka uç parametreleri",
    "Unsatisfied authentication mechanism parameters" : "Yetersiz kimlik doğrulama mekanizması parametreleri",
    "Insufficient data: %s" : "Yetersiz veri: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "\"%i\" kimliği ile bir depolama bulunamadı",
    "Personal" : "Kişisel",
    "System" : "Sistem",
    "Grant access" : "Erişimi sağla",
    "Access granted" : "Giriş kabul edildi",
    "Error configuring OAuth1" : "OAuth1 yapılandırma hatası",
    "Error configuring OAuth2" : "OAuth2 yapılandırma hatası",
    "Generate keys" : "Anahtarlar üret",
    "Error generating key pair" : "Anahtar çifti üretirken hata",
    "Enable encryption" : "Şifrelemeyi aç",
    "Enable previews" : "Önizlemeleri aç",
    "Enable sharing" : "Paylaşımı etkinleştir",
    "Check for changes" : "Değişiklikleri denetle",
    "Never" : "Daha yeni",
    "Once every direct access" : "Her doğrudan erişimde bir kez",
    "All users. Type to select user or group." : "Tüm kullanıcılar. Kullanıcı veya grup seçmek için yazın.",
    "(group)" : "(grup)",
    "Admin defined" : "Yönetici tanımlandı",
    "Saved" : "Kaydedildi",
    "Empty response from the server" : "Sunucudan boş yanıt",
    "Couldn't access. Please logout and login to activate this mount point" : "Erişilemedi. Lütfen bu bağlama noktasını etkinleştirmek için tekrar oturumu kapatıp açın.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud sunucusundan bilgi alınamadı: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Harici bağlama noktalarının listesi alınamadı: {type}",
    "There was an error with message: " : "Şu mesajla bir hata oluştu:",
    "External mount error" : "Harici bağlama hatası",
    "Username" : "Kullanıcı Adı",
    "Password" : "Parola",
    "Save" : "Kaydet",
    "Access key" : "Erişim anahtarı",
    "Secret key" : "Gizli anahtar",
    "Builtin" : "Yerleşik",
    "None" : "Hiçbiri",
    "OAuth1" : "OAuth1",
    "App key" : "Uyg. anahtarı",
    "App secret" : "Uyg. parolası",
    "OAuth2" : "OAuth2",
    "Client ID" : "İstemci kimliği",
    "Client secret" : "İstemci parolası",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Kiracı adı",
    "Identity endpoint URL" : "Kimlik uç nokta URL'si",
    "Rackspace" : "Rackspace",
    "API key" : "API anahtarı",
    "Username and password" : "Kullanıcı adı ve parola",
    "RSA public key" : "RSA ortak anahtarı",
    "Public key" : "Ortak anahtar",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Makine adı",
    "Port" : "Port",
    "Region" : "Bölge",
    "Enable SSL" : "SSL'yi Etkinleştir",
    "Enable Path Style" : "Yol Biçemini Etkinleştir",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Uzak alt klasör",
    "Secure https://" : "Güvenli https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Sunucu",
    "Secure ftps://" : "Güvenli ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Yerel",
    "Location" : "Konum",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Kök",
    "SFTP with secret key login" : "Gizli anahtar oturumu ile SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Paylaş",
    "Domain" : "Alan adı",
    "SMB / CIFS using OC login" : "OC oturumu kullanarak SMB / CIFS",
    "Username as share" : "Paylaşım olarak kullanıcı adı",
    "OpenStack Object Storage" : "OpenStack Nesne Depolama",
    "Service name" : "Hizmet adı",
    "Request timeout (seconds)" : "İstek zamanaşımı (saniye)",
    "<b>Note:</b> " : "<b>Not:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> PHP'de cURL desteği etkin veya kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> PHP'de FTP desteği etkin veya kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Not:</b> \"%s\" kurulu değil. %s bağlaması mümkün olmayacak. Lütfen kurulumu için sistem yöneticilerinizle iletişime geçin.",
    "No external storage configured" : "Yapılandırılmış harici depolama yok",
    "You can add external storages in the personal settings" : "Harici depolamaları kişisel ayarlar içerisinden ekleyebilirsiniz",
    "Name" : "Ad",
    "Storage type" : "Depolama türü",
    "Scope" : "Kapsam",
    "External Storage" : "Harici Depolama",
    "Folder name" : "Klasör ismi",
    "Authentication" : "Kimlik Doğrulama",
    "Configuration" : "Yapılandırma",
    "Available for" : "Kullanabilenler",
    "Add storage" : "Depo ekle",
    "Advanced settings" : "Gelişmiş ayarlar",
    "Delete" : "Sil",
    "Allow users to mount external storage" : "Kullanıcılara harici depolama bağlamalarına izin ver",
    "Allow users to mount the following external storage" : "Kullanıcıların aşağıdaki harici depolamayı bağlamalarına izin ver"
},
"nplurals=2; plural=(n > 1);");
